VideoPlayerApi class

Constructors

VideoPlayerApi()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(CreateMessage arg) → Future<TextureMessage>
dispose(TextureMessage arg) → Future<void>
initialize() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(TextureMessage arg) → Future<void>
play(TextureMessage arg) → Future<void>
position(TextureMessage arg) → Future<PositionMessage>
seekTo(PositionMessage arg) → Future<void>
setLooping(LoopingMessage arg) → Future<void>
setMixWithOthers(MixWithOthersMessage arg) → Future<void>
setPlaybackSpeed(PlaybackSpeedMessage arg) → Future<void>
setVolume(VolumeMessage arg) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited