MethodChannelVideoPlayer class

An implementation of VideoPlayerPlatform that uses method channels.

Inheritance

Constructors

MethodChannelVideoPlayer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isMock → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildView(int textureId) → Widget
Returns a widget displaying the video with a given textureID.
override
create(DataSource dataSource) → Future<int?>
override
dispose(int textureId) → Future<void>
override
errorListener(int textureId) → Future<bool>
inherited
getPosition(int textureId) → Future<Duration>
Gets the video position as Duration from the start.
override
init() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(int textureId) → Future<void>
Stops the video playback.
override
play(int textureId) → Future<void>
Starts the video playback.
override
seekTo(int textureId, Duration position) → Future<void>
Sets the video position to a Duration from the start.
override
setLooping(int textureId, bool looping) → Future<void>
override
setMixWithOthers(bool mixWithOthers) → Future<void>
Sets the audio mode to mix with other sources
override
setPlaybackSpeed(int textureId, double speed) → Future<void>
Sets the playback speed to a speed value indicating the playback rate.
override
setVolume(int textureId, double volume) → Future<void>
Sets the volume to a range between 0.0 and 1.0.
override
toString() → String
A string representation of this object.
inherited
videoEventsFor(int textureId) → Stream<VideoEvent>
override
videoSpectrumEventsFor(int textureId) → Stream<VideoSpectrumEvent>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited