DataSource class

Description of the data source used to create an instance of the video player.

Constructors

DataSource({required DataSourceType sourceType, String? uri, VideoFormat? formatHint, String? asset, String? package, Map<String, String> httpHeaders = const {}})
Constructs an instance of DataSource.

Properties

asset → String?
The name of the asset. Only set for DataSourceType.asset videos.
final
formatHint → VideoFormat?
Android only. Will override the platform's generic file format detection with whatever is set here.
final
hashCode → int
The hash code for this object.
no setterinherited
httpHeaders ↔ Map<String, String>
HTTP headers used for the request to the uri. Only for DataSourceType.network videos. Always empty for other video types.
getter/setter pair
package → String?
The package that the asset was loaded from. Only set for DataSourceType.asset videos.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceType → DataSourceType
The way in which the video was originally loaded.
final
uri → String?
The URI to the video file.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited