DurationRange class

Describes a discrete segment of time within a video using a start and end Duration.

Constructors

DurationRange(Duration start, Duration end)
Trusts that the given start and end are actually in order. They should both be non-null.

Properties

end → Duration
The end of the segment described as a duration relative to the beginning of the entire video. This is expected to be non-null and longer than or equal to start.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → Duration
The beginning of the segment described relative to the beginning of the entire video. Should be shorter than or equal to end.
final

Methods

endFraction(Duration duration) → double
Assumes that duration is the total length of the video that this DurationRange is a segment form. It returns the percentage that start is through the entire video.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startFraction(Duration duration) → double
Assumes that duration is the total length of the video that this DurationRange is a segment form. It returns the percentage that start is through the entire video.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override