VideoEvent class

Event emitted from the platform implementation.

Constructors

VideoEvent({required VideoEventType eventType, Duration? duration, Size? size, List<DurationRange>? buffered})
Creates an instance of VideoEvent.

Properties

buffered → List<DurationRange>?
Buffered parts of the video.
final
duration → Duration?
Duration of the video.
final
eventType → VideoEventType
The type of the event.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size?
Size of the video.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override