VideoPlayerOptions class

VideoPlayerOptions can be optionally used to set additional player settings

Constructors

VideoPlayerOptions({bool mixWithOthers = false})
set additional optional player settings

Properties

hashCode → int
The hash code for this object.
no setterinherited
mixWithOthers → bool
Set this to true to mix the video players audio with other audio sources. The default value is false
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited