VideoPlayerPlatform class abstract

Implementers

Constructors

VideoPlayerPlatform()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isMock → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildView(int textureId) → Widget
Returns a widget displaying the video with a given textureID.
create(DataSource dataSource) → Future<int?>
dispose(int textureId) → Future<void>
errorListener(int textureId) → Future<bool>
getPosition(int textureId) → Future<Duration>
Gets the video position as Duration from the start.
init() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(int textureId) → Future<void>
Stops the video playback.
play(int textureId) → Future<void>
Starts the video playback.
seekTo(int textureId, Duration position) → Future<void>
Sets the video position to a Duration from the start.
setLooping(int textureId, bool looping) → Future<void>
setMixWithOthers(bool mixWithOthers) → Future<void>
Sets the audio mode to mix with other sources
setPlaybackSpeed(int textureId, double speed) → Future<void>
Sets the playback speed to a speed value indicating the playback rate.
setVolume(int textureId, double volume) → Future<void>
Sets the volume to a range between 0.0 and 1.0.
toString() → String
A string representation of this object.
inherited
videoEventsFor(int textureId) → Stream<VideoEvent>
videoSpectrumEventsFor(int textureId) → Stream<VideoSpectrumEvent>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ VideoPlayerPlatform
getter/setter pair