VideoSpectrumEvent class

Constructors

VideoSpectrumEvent({required int sampleRateHz, required int channelCount, required List<double> fft})

Properties

channelCount → int
final
fft → List<double>
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRateHz → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override