CreateMessage class

Constructors

CreateMessage()

Properties

asset ↔ String
getter/setter pair
formatHint ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
httpHeaders ↔ Map<Object, Object>
getter/setter pair
packageName ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri ↔ String
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object message) → CreateMessage